==> jscad__obj-serializer-2.1.7.jar: META-INF/resources/webjars/jscad__obj-serializer/2.1.7/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

## [2.1.7](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/obj-serializer@2.1.6...@jscad/obj-serializer@2.1.7) (2022-04-03)

**Note:** Version bump only for package @jscad/obj-serializer





## [2.1.6](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/obj-serializer@2.1.5...@jscad/obj-serializer@2.1.6) (2022-04-03)

**Note:** Version bump only for package @jscad/obj-serializer





## [2.1.5](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/obj-serializer@2.1.4...@jscad/obj-serializer@2.1.5) (2022-03-13)

**Note:** Version bump only for package @jscad/obj-serializer





## [2.1.4](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/obj-serializer@2.1.3...@jscad/obj-serializer@2.1.4) (2022-03-06)

**Note:** Version bump only for package @jscad/obj-serializer





## [2.1.3](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/obj-serializer@2.1.2...@jscad/obj-serializer@2.1.3) (2022-02-19)

**Note:** Version bump only for package @jscad/obj-serializer





## [2.1.2](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/obj-serializer@2.1.1...@jscad/obj-serializer@2.1.2) (2021-12-26)

**Note:** Version bump only for package @jscad/obj-serializer





## [2.1.1](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/obj-serializer@2.1.0...@jscad/obj-serializer@2.1.1) (2021-12-11)

**Note:** Version bump only for package @jscad/obj-serializer





# 2.1.0 (2021-11-07)


### Bug Fixes

* **obj-serializer:** added default material when serializing objects without colors ([#947](https://github.com/jscad/OpenJSCAD.org/issues/947)) ([843865b](https://github.com/jscad/OpenJSCAD.org/commit/843865b94f4d348ea67523b6d442f9c562bef021))


### Features

* **io:** new serializer for OBJ ([#942](https://github.com/jscad/OpenJSCAD.org/issues/942)) ([baaae18](https://github.com/jscad/OpenJSCAD.org/commit/baaae18ad55252ec71b074bd85dea7d137a22eb8))





# 2.0.0 (2021-10-25)

### Features

* **obj-serializer:** create OBJ serializer (#515)





**Note:** Version bump only for package @jscad/obj-serializer

==> jscad__obj-serializer-2.1.13.jar: META-INF/resources/webjars/jscad__obj-serializer/2.1.13/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

## [2.1.13](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/obj-serializer@2.1.12...@jscad/obj-serializer@2.1.13) (2022-11-26)

**Note:** Version bump only for package @jscad/obj-serializer





## [2.1.12](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/obj-serializer@2.1.11...@jscad/obj-serializer@2.1.12) (2022-08-21)

**Note:** Version bump only for package @jscad/obj-serializer





## [2.1.11](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/obj-serializer@2.1.10...@jscad/obj-serializer@2.1.11) (2022-07-17)

**Note:** Version bump only for package @jscad/obj-serializer





## [2.1.10](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/obj-serializer@2.1.9...@jscad/obj-serializer@2.1.10) (2022-06-12)

**Note:** Version bump only for package @jscad/obj-serializer





## [2.1.9](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/obj-serializer@2.1.8...@jscad/obj-serializer@2.1.9) (2022-05-15)

**Note:** Version bump only for package @jscad/obj-serializer





## [2.1.8](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/obj-serializer@2.1.7...@jscad/obj-serializer@2.1.8) (2022-04-24)

**Note:** Version bump only for package @jscad/obj-serializer





## [2.1.7](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/obj-serializer@2.1.6...@jscad/obj-serializer@2.1.7) (2022-04-03)

**Note:** Version bump only for package @jscad/obj-serializer





## [2.1.6](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/obj-serializer@2.1.5...@jscad/obj-serializer@2.1.6) (2022-04-03)

**Note:** Version bump only for package @jscad/obj-serializer





## [2.1.5](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/obj-serializer@2.1.4...@jscad/obj-serializer@2.1.5) (2022-03-13)

**Note:** Version bump only for package @jscad/obj-serializer





## [2.1.4](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/obj-serializer@2.1.3...@jscad/obj-serializer@2.1.4) (2022-03-06)

**Note:** Version bump only for package @jscad/obj-serializer





## [2.1.3](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/obj-serializer@2.1.2...@jscad/obj-serializer@2.1.3) (2022-02-19)

**Note:** Version bump only for package @jscad/obj-serializer





## [2.1.2](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/obj-serializer@2.1.1...@jscad/obj-serializer@2.1.2) (2021-12-26)

**Note:** Version bump only for package @jscad/obj-serializer





## [2.1.1](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/obj-serializer@2.1.0...@jscad/obj-serializer@2.1.1) (2021-12-11)

**Note:** Version bump only for package @jscad/obj-serializer





# 2.1.0 (2021-11-07)


### Bug Fixes

* **obj-serializer:** added default material when serializing objects without colors ([#947](https://github.com/jscad/OpenJSCAD.org/issues/947)) ([843865b](https://github.com/jscad/OpenJSCAD.org/commit/843865b94f4d348ea67523b6d442f9c562bef021))


### Features

* **io:** new serializer for OBJ ([#942](https://github.com/jscad/OpenJSCAD.org/issues/942)) ([baaae18](https://github.com/jscad/OpenJSCAD.org/commit/baaae18ad55252ec71b074bd85dea7d137a22eb8))





# 2.0.0 (2021-10-25)

### Features

* **obj-serializer:** create OBJ serializer (#515)





**Note:** Version bump only for package @jscad/obj-serializer
